@@ -30,6 +30,8 @@ router.register(r'calibration', CalibrationViewSet)
 router.register(r'hubs', HubViewSet)
 router.register(r'io', IOViewSet)
 
+from OpenHubAPI.data.views.views import index
+
 # Wire up our API using automatic URL routing.
 # Additionally, we include login URLs for the browsable API.
 urlpatterns = [
@@ -37,7 +39,7 @@ urlpatterns = [
     path('api-auth/', include('rest_framework.urls', namespace='rest_framework')),
     # path('start', views.start, name='start'),
     # path('calibrate', views.start, name='calibrate'),
-    path('index', OpenHubAPI.data.views.views.index, name='index'),
+    path('index', index, name='index'),
     url(r'^admin/', admin.site.urls),
     path('post/ajax/hardware', HardwareViewSet.postHardware, name="post_hardware"),
     path('post/ajax/hardware/form_type/', HardwareViewSet.getHardwareTypeForm,
